Skip to contents

Comparison Maker

Usage

comparison_maker(data, x, comparisons = "all")

Arguments

data

The dataset you are inputting

x

The column name that contains the groups you are wanting to compare

comparisons

Default is "all". If you do not want to compare all variables to each other within your grouping column, then you can specify which comparisons you want instead.

Value

comparisons

Examples

comparison_maker(ToothGrowth, supp)
#> [[1]]
#> [1] "OJ" "VC"
#>