comparison_maker.Rd
Comparison Maker
comparison_maker(data, x, comparisons = "all")
The dataset you are inputting
The column name that contains the groups you are wanting to compare
Default is "all". If you do not want to compare all variables to each other within your grouping column, then you can specify which comparisons you want instead.
comparisons
comparison_maker(ToothGrowth, supp) #> [[1]] #> [1] "OJ" "VC" #>